@@ -16,6 +16,7 @@ usePreCalcResultsExtra <- FALSE
 ### code chunk number 2: preliminaries
 ###################################################
 options(prompt = 'R> ', continue = '+  ')
+plotevery <- 10L # can be used for trace plots to make vignette smaller
 
 
 ###################################################
@@ -40,14 +41,14 @@ plot(sim)
 
 
 ###################################################
-### code chunk number 5: article.Rnw:239-241 (eval = FALSE)
+### code chunk number 5: article.Rnw:240-242 (eval = FALSE)
 ###################################################
 ## res <- svsample(ret, priormu = c(-10, 1), priorphi = c(20, 1.1),
 ##   priorsigma = 0.1)
 
 
 ###################################################
-### code chunk number 6: article.Rnw:244-250
+### code chunk number 6: article.Rnw:245-251
 ###################################################
 if (usePreCalcResultsExtra) {
  load("vignette_sampling_draws1.RData")
@@ -58,7 +59,7 @@ if (usePreCalcResultsExtra) {
 
 
 ###################################################
-### code chunk number 7: article.Rnw:272-273
+### code chunk number 7: article.Rnw:273-274
 ###################################################
 summary(res, showlatent = FALSE)
 
@@ -104,7 +105,7 @@ plot(myresid, ret)
 
 
 ###################################################
-### code chunk number 14: article.Rnw:404-410
+### code chunk number 14: article.Rnw:405-411
 ###################################################
 set.seed(123456)
 n <- 1000
@@ -115,7 +116,7 @@ y <- rnorm(n, X %*% beta.true, sigma.true)
 
 
 ###################################################
-### code chunk number 15: article.Rnw:414-420
+### code chunk number 15: article.Rnw:415-421
 ###################################################
 burnin <- 100
 draws <- 5000
@@ -126,7 +127,7 @@ C0 <- 0.001
 
 
 ###################################################
-### code chunk number 16: article.Rnw:423-427
+### code chunk number 16: article.Rnw:424-428
 ###################################################
 p <- ncol(X)
 preCov <- solve(crossprod(X) + B0inv)
@@ -135,7 +136,7 @@ preDf <- c0 + n/2 + p/2
 
 
 ###################################################
-### code chunk number 17: article.Rnw:430-433
+### code chunk number 17: article.Rnw:431-434
 ###################################################
 draws1 <- matrix(NA_real_, nrow = draws, ncol = p + 1)
 colnames(draws1) <- c(paste("beta", 0:(p-1), sep = "_"), "sigma")
@@ -143,7 +144,7 @@ sigma2draw <- 1
 
 
 ###################################################
-### code chunk number 18: article.Rnw:436-444
+### code chunk number 18: article.Rnw:437-445
 ###################################################
 for (i in -(burnin-1):draws) {
   betadraw <- as.numeric(mvtnorm::rmvnorm(1, preMean,
@@ -156,7 +157,7 @@ for (i in -(burnin-1):draws) {
 
 
 ###################################################
-### code chunk number 19: article.Rnw:447-448
+### code chunk number 19: article.Rnw:448-449
 ###################################################
 colMeans(draws1)
 
@@ -165,17 +166,17 @@ colMeans(draws1)
 ### code chunk number 20: homo
 ###################################################
 par(mar = c(3.1, 1.8, 1.9, .5), mgp = c(1.8, .6, 0))
-plot(coda::mcmc(draws1), show.obs = FALSE)
+plot(coda::mcmc(draws1[seq(1L, nrow(draws1), by = plotevery),]), show.obs = FALSE)
 
 
 ###################################################
-### code chunk number 21: article.Rnw:458-459 (eval = FALSE)
+### code chunk number 21: article.Rnw:459-460 (eval = FALSE)
 ###################################################
 ## plot(coda::mcmc(draws1), show.obs = FALSE)
 
 
 ###################################################
-### code chunk number 22: article.Rnw:481-486
+### code chunk number 22: article.Rnw:482-487
 ###################################################
 mu.true <- log(sigma.true^2)
 phi.true <- 0.97
@@ -185,7 +186,7 @@ y <- X %*% beta.true + simresid$y
 
 
 ###################################################
-### code chunk number 23: article.Rnw:489-495
+### code chunk number 23: article.Rnw:490-496
 ###################################################
 draws <- 50000
 burnin <- 1000
@@ -196,7 +197,7 @@ priorsigma <- 1
 
 
 ###################################################
-### code chunk number 24: article.Rnw:498-505
+### code chunk number 24: article.Rnw:499-506
 ###################################################
 draws2 <- matrix(NA_real_, nrow = floor(draws / thinning),
   ncol = 3 + n + p)
@@ -208,7 +209,7 @@ svdraw <- list(para = c(mu = -10, phi = 0.9, sigma = 0.2),
 
 
 ###################################################
-### code chunk number 25: article.Rnw:512-529 (eval = FALSE)
+### code chunk number 25: article.Rnw:513-530 (eval = FALSE)
 ###################################################
 ## for (i in -(burnin-1):draws) {
 ##   ytilde <- y - X %*% betadraw
@@ -230,7 +231,7 @@ svdraw <- list(para = c(mu = -10, phi = 0.9, sigma = 0.2),
 
 
 ###################################################
-### code chunk number 26: article.Rnw:532-561
+### code chunk number 26: article.Rnw:533-562
 ###################################################
 if (usePreCalcResults) {
  load("vignette_sampling_draws2.RData")
@@ -264,7 +265,7 @@ for (i in -(burnin-1):draws) {
 
 
 ###################################################
-### code chunk number 27: article.Rnw:565-566 (eval = FALSE)
+### code chunk number 27: article.Rnw:566-567 (eval = FALSE)
 ###################################################
 ## plot(coda::mcmc(draws2[, 4:7]), show.obs = FALSE)
 
@@ -273,17 +274,17 @@ for (i in -(burnin-1):draws) {
 ### code chunk number 28: hetero
 ###################################################
 par(mar = c(3.1, 1.8, 1.9, .5), mgp = c(1.8, .6, 0))
-plot(coda::mcmc(draws2selection[, 1:4]), show.obs = FALSE)
+plot(coda::mcmc(draws2selection[seq(1L, nrow(draws2selection), by = plotevery), 1:4]), show.obs = FALSE)
 
 
 ###################################################
-### code chunk number 29: article.Rnw:584-585 (eval = FALSE)
+### code chunk number 29: article.Rnw:585-586 (eval = FALSE)
 ###################################################
 ## colMeans(draws2[, 4:8])
 
 
 ###################################################
-### code chunk number 30: article.Rnw:588-589
+### code chunk number 30: article.Rnw:589-590
 ###################################################
 colMeans(draws2selection)
 
@@ -302,7 +303,7 @@ abline(0,1)
 
 
 ###################################################
-### code chunk number 32: article.Rnw:654-875
+### code chunk number 32: article.Rnw:655-876
 ###################################################
 if (usePreCalcResults) {
  load("vignette_sampling_realworld.RData")
@@ -551,17 +552,20 @@ lines(density(realresselection[[2]][,"beta_1"], bw="SJ", adjust=smootherfactor),
 #lines(confint(ols)[2,], rep(0,2), col=2)
 legend("topright", c("SV", "GARCH", "homosked."), col=c(1,4,2), lty=1:3)
 
-plotorder <- sample.int(3*nrow(realresselection[[1]]))
-cols <- rep(c("#000000aa", "#0000ff66", "#ff000077"), each=nrow(realresselection[[1]]))[plotorder]
-pchs <- rep(1:3, each=nrow(realresselection[[1]]))[plotorder]
+showevery <- 2L
+plotorder <- sample.int(3*(nrow(realresselection[[1]]) / showevery))
+cols <- rep(c("#000000bb", "#0000ff88", "#ff000088"),
+	    each = nrow(realresselection[[1]]) / showevery)[plotorder]
+pchs <- rep(1:3, each=nrow(realresselection[[1]]) / showevery)[plotorder]
 
-beta0 <- c(realresselection[[1]][,"beta_0"],
-	   realresselection[[3]][,"beta_0"],
-	   realresselection[[2]][,"beta_0"])[plotorder]
+myseq <- seq(1, nrow(realresselection[[1]]), by = showevery)
+beta0 <- c(realresselection[[1]][myseq,"beta_0"],
+	   realresselection[[3]][myseq,"beta_0"],
+	   realresselection[[2]][myseq,"beta_0"])[plotorder]
 
-beta1 <- c(realresselection[[1]][,"beta_1"],
-	   realresselection[[3]][,"beta_1"],
-	   realresselection[[2]][,"beta_1"])[plotorder]
+beta1 <- c(realresselection[[1]][myseq,"beta_1"],
+	   realresselection[[3]][myseq,"beta_1"],
+	   realresselection[[2]][myseq,"beta_1"])[plotorder]
 
 plot(beta0, beta1, col=cols, pch=pchs,
     xlab=bquote(paste("p(",beta[0],"|", bold(y), ")")),
